summaryrefslogtreecommitdiffstats
path: root/02_exercise/prompt_utils.h
diff options
context:
space:
mode:
Diffstat (limited to '02_exercise/prompt_utils.h')
-rw-r--r--02_exercise/prompt_utils.h9
1 files changed, 4 insertions, 5 deletions
diff --git a/02_exercise/prompt_utils.h b/02_exercise/prompt_utils.h
index a3a9d9e..36d065d 100644
--- a/02_exercise/prompt_utils.h
+++ b/02_exercise/prompt_utils.h
@@ -1,11 +1,10 @@
#ifndef PROMPT_UTILS_H_INCLUDED
#define PROMPT_UTILS_H_INCLUDED
-#include <stddef.h>
-
-// Returns the relative path to get from the `from_dir` to the `to_dir`
+// returns the relative path to get from the `from_dir` to the `to_dir`
char const *relative_path(char const *from_dir, char const *to_dir);
-// Returns the position of each occurence of the seperator
-size_t *get_seperator_indeces(char const *text, char seperator);
+// returns the position of each occurrence of the separator
+size_t *get_separator_indices(char const *text, char separator);
+
#endif // PROMPT_UTILS_H_INCLUDED